# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/CloudWatchLogs2Pandas',
                'doc_host': 'https://guyernest.github.io',
                'git_url': 'https://github.com/guyernest/CloudWatchLogs2Pandas',
                'lib_path': 'CloudWatchLogs2Pandas'},
  'syms': { 'CloudWatchLogs2Pandas.CloudWatchQuery': { 'CloudWatchLogs2Pandas.CloudWatchQuery.CloudWatchQuery': ( 'cloudwatchquery.html#cloudwatchquery',
                                                                                                                  'CloudWatchLogs2Pandas/CloudWatchQuery.py'),
                                                       'CloudWatchLogs2Pandas.CloudWatchQuery.CloudWatchQuery.__init__': ( 'cloudwatchquery.html#cloudwatchquery.__init__',
                                                                                                                           'CloudWatchLogs2Pandas/CloudWatchQuery.py'),
                                                       'CloudWatchLogs2Pandas.CloudWatchQuery.CloudWatchQuery.add_log_group': ( 'cloudwatchquery.html#cloudwatchquery.add_log_group',
                                                                                                                                'CloudWatchLogs2Pandas/CloudWatchQuery.py'),
                                                       'CloudWatchLogs2Pandas.CloudWatchQuery.CloudWatchQuery.get_df': ( 'cloudwatchquery.html#cloudwatchquery.get_df',
                                                                                                                         'CloudWatchLogs2Pandas/CloudWatchQuery.py'),
                                                       'CloudWatchLogs2Pandas.CloudWatchQuery.CloudWatchQuery.set_region': ( 'cloudwatchquery.html#cloudwatchquery.set_region',
                                                                                                                             'CloudWatchLogs2Pandas/CloudWatchQuery.py')},
            'CloudWatchLogs2Pandas.core': {'CloudWatchLogs2Pandas.core.foo': ('core.html#foo', 'CloudWatchLogs2Pandas/core.py')}}}


# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_CloudWatchQuery.ipynb.

# %% auto 0
__all__ = ['CloudWatchQuery']

# %% ../nbs/00_CloudWatchQuery.ipynb 14
import awswrangler as wr
import pandas as pd
from datetime import datetime, timedelta
import boto3

class CloudWatchQuery:
    "Configure a  CloudWatch query"
    def __init__(self, query:str, log_group:str): 
        self.query = query 
        self.log_groups = []
        self.log_groups.append(log_group)
        self.region = "us-west-2"
        
    def add_log_group(self, log_group:str):
        self.log_groups.append(log_group)
        
    def get_df(self, 
              days_start:int = 14, # number of days in the past to start
              hours_start:int = 0, # number of hours in the past to start
              days_end:int = 0, # number of days in the past to end
              hours_end:int = 0): # number of hours in the past to end
        "Execute the query"
        df = wr.cloudwatch.read_logs(
            log_group_names=self.log_groups,
            query=self.query,
            start_time=datetime.now()- timedelta(days=days_start, hours=hours_start),
            end_time=datetime.now()- timedelta(days=days_end, hours=hours_end),

            boto3_session = boto3.Session(region_name=self.region)
        )
        return df

# %% ../nbs/00_CloudWatchQuery.ipynb 15
from fastcore.foundation import patch

@patch
def set_region(self:CloudWatchQuery, region:str):
    "Set the region of the query."
    self.region = region
